@@ -13,7 +13,7 @@ from itertools import count, groupby
 import requests
 from Bio.PDB import MMCIFIO, Select, PDBParser, PDBIO
 from Bio.PDB.MMCIFParser import MMCIFParser
-from mysolr import Solr
+from pysolr import Solr
 import logging, sys
 
 from requests import HTTPError
@@ -630,7 +630,7 @@ class SequenceException(Exception):
 
 class PDBeSolrSearch:
     def __init__(self):
-        self.solr = Solr(PDBE_SOLR_URL, version=4)
+        self.solr = Solr(PDBE_SOLR_URL)
         logging.basicConfig(level=logging.INFO, stream=sys.stdout,
                             format='LOG|%(asctime)s|%(levelname)s  %(message)s', datefmt='%d-%b-%Y %H:%M:%S')
         logging.getLogger("requests").setLevel(logging.WARNING)
@@ -651,7 +651,7 @@ class PDBeSolrSearch:
         try:
             query = {"rows": UNLIMITED_ROWS, "fl": field_list, "q": self.join_with_AND(query_details)}
             response = self.solr.search(**query)
-            documents = response.documents
+            documents = response.docs
             if DEBUG:
                 logging.getLogger().debug("Found %d matching entities in %d entries." % (
                     len(documents), len({rd["pdb_id"] for rd in documents})))
@@ -903,3 +903,18 @@ class PdbMetaData(PDBeSolrSearch):
             # desc = desc[0].text.capitalize() if desc else None
             #
             # return (doi, pubmed, desc, title, src, key, molecutag)
+
+
+class UniprotInfo():
+    def __init__(self, uniid):
+        self.uniid = uniid
+
+    def get_sequence(self):
+        url_from = 'https://www.uniprot.org/uniprot/{}.fasta'.format(self.uniid)
+        seq = None
+        with urllib.request.urlopen(url_from) as url:
+            data = url.read().decode()
+            seq = ''
+            for line in data.split('\n'):
+                seq += line if not line.startswith('>') else ''
+        return seq
